@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.051
+Version 0.052
 
 =cut
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 
 =head1 SYNOPSIS
@@ -113,9 +113,7 @@ Depends on $attr->{Async} and callback:
 
 =head1 METHODS
 
-=head2 new
-
-Parent method of L<Mojo::Pg#new>
+All methods from parent module L<Mojo::Pg> are inherits and implements the following new ones.
 
 =head2 connect
 
@@ -123,17 +121,15 @@ DBI-style of new object instance. See L<DBI#connect>
 
 =head2 query
 
-Is same as L<Mojo::Pg::Database#query>.
+Like L<Mojo::Pg::Database#query> but input params - L<Mojo::Pg::Che#Params-for-quering-methods>
 
 Blocking query without attr B<Async> or callback.
 
 Non-blocking query with attr B<Async> or callback.
 
-Statement handler as first param is allow.
-
 =head2 db
 
-Parent method of L<Mojo::Pg#db>.
+Overriden method of L<Mojo::Pg#db>. Because can first input param - DBI database handler (when prepared statement used).
 
 =head2 prepare
 
@@ -145,36 +141,51 @@ Prepare and return DBI cached statement handler for query string.
 
 =head2 selectrow_array
 
-DBI style quering. See L<DBI#selectrow_array>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectrow_array>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectrow_arrayref
 
-DBI style quering. See L<DBI#selectrow_arrayref>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectrow_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectrow_hashref
 
-DBI style quering. See L<DBI#selectrow_hashref>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectrow_hashref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectall_arrayref
 
-DBI style quering. See L<DBI#selectall_arrayref>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectall_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectall_hashref
 
-DBI style quering. See L<DBI#selectall_hashref>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectall_hashref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectcol_arrayref
 
-DBI style quering. See L<DBI#selectcol_arrayref>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#selectcol_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 do
 
-DBI style quering. See L<DBI#do>. Blocking|non-blocking, query string|statement handler.
+DBI style quering. See L<DBI#do>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 begin
 
 Start transaction and return new <Mojo::Pg::Che::Database> object which attr C< {tx} > is a <Mojo::Pg::Transaction> object. Sinonyms are: C<< ->tx >> and C<< ->begin_work >>.
 
+=head1 Params for quering methods
+
+The methods C<query>, C<select...>, C<do> has next input params:
+
+=over 4
+
+=item * String query | statement handler object
+
+=item * Hashref attrs (optional)
+
+=item * Array of bind values (optional)
+
+=item * Callback non-blocking (optional)
+
+=back
 
 =head1 AUTHOR
 
